@@ -1,7 +1,7 @@
 /*
  GNU Maverik - a system for managing display and interaction in 
                Virtual Environment applications.
- Copyright (C) 1999-2000 Advanced Interfaces Group
+ Copyright (C) 1999-2001 Advanced Interfaces Group
 
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
@@ -31,7 +31,7 @@
 int main(int argc, char *argv[])
 {
   /* Initialise the Maverik system */
-  mav_initialise();
+  mav_initialise(&argc, argv);
 
   /* Rendering loop */
   while (1) {
