@@ -1,7 +1,7 @@
 /*
  GNU Maverik - a system for managing display and interaction in 
                Virtual Environment applications.
- Copyright (C) 1999-2000 Advanced Interfaces Group
+ Copyright (C) 1999-2001 Advanced Interfaces Group
 
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
@@ -29,6 +29,7 @@
 #include "maverik.h"
 #include <stdio.h>
 #include <math.h>
+#include <stdlib.h>
 
 MAV_surfaceParams *sp[4];
 MAV_matrix *objMat1, *objMat2;
@@ -125,7 +126,7 @@ int compEvent(MAV_object *obj, MAV_mouseEvent *ev)
 }
 
 /* Display a help message */
-void helpMsg(void)
+void helpMsg(void *ignored)
 {
  mav_stringDisplay(mav_win_all, "Left mouse button - navigate forward/backward and yaw", MAV_COLOUR_BLACK, 0, -0.95, 0.90);
   mav_stringDisplay(mav_win_all, "Right mouse button - navigate up/down and left/right", MAV_COLOUR_BLACK, 0, -0.95, 0.83);
@@ -141,7 +142,7 @@ void helpMsg(void)
 }
 
 /* Routine to make object jump */
-void jump(void)
+void jump(void *ignored)
 {
   /* Increase Y component of matrix by an ammount which ranges +4 to -4 over 60 interactions */
   objMat1->mat[MAV_MATRIX_YCOMP]+=cos(MAV_DEG2RAD(fc*3.0))*4.0;
@@ -150,12 +151,12 @@ void jump(void)
   fc++;
   if (fc>60) {
     fc=0;
-    mav_frameFn1Rmv(jump);
+    mav_frameFn1Rmv(jump, NULL);
   }
 }
 
 /* Routine to drag object with mouse */
-void pick(void)
+void pick(void *ignored)
 {
   MAV_vector pos;
 
@@ -181,11 +182,11 @@ int keyEvent(MAV_object *obj, MAV_keyboardEvent *ke)
   case 'h': /* Help */    
     if (ke->movement==MAV_PRESSED)
     {
-      mav_frameFn3Add(helpMsg); /* Begin executing function helpMsg at the end of each frame */
+      mav_frameFn3Add(helpMsg, NULL); /* Begin executing function helpMsg at the end of each frame */
     }
     else
     {
-      mav_frameFn3Rmv(helpMsg); /* Stop executing function helpMsg at the end of each frame */
+      mav_frameFn3Rmv(helpMsg, NULL); /* Stop executing function helpMsg at the end of each frame */
     }
     break;
   }
@@ -218,7 +219,7 @@ int keyEvent(MAV_object *obj, MAV_keyboardEvent *ke)
       case 'j': /* Make object jump */
         if (fc==0) { /* Only if something is not currently in flight */
           if (mav_callbackGetMatrixExec(mav_win_current, ke->obj, &objMat1)) { /* Get a ptr to the matrix field of the object */
-	    mav_frameFn1Add(jump); /* Begin executing function jump at the start of each frame */
+	    mav_frameFn1Add(jump, NULL); /* Begin executing function jump at the start of each frame */
 	  }
 	}
         break;
@@ -231,12 +232,12 @@ int keyEvent(MAV_object *obj, MAV_keyboardEvent *ke)
       {
         if (mav_callbackGetMatrixExec(mav_win_current, ke->obj, &objMat2)) { /* Get a ptr to the matrix field of the object */
 	  objDist= ke->objint.pt1; /* Remember distance from eye to object intersection */
-	  mav_frameFn2Add(pick); /* Begin executing function pick after the view has been set */
+	  mav_frameFn2Add(pick, NULL); /* Begin executing function pick after the view has been set */
 	}
       }
       else
       {
-        mav_frameFn2Rmv(pick); /* Stop executing function pick after the view has been set */
+        mav_frameFn2Rmv(pick, NULL); /* Stop executing function pick after the view has been set */
       }
       break;
     }
@@ -556,17 +557,17 @@ void myMove(int i)
   mav_SMSDelete(tmp, MAV_FALSE);
 }
 
-void myMove0(void)
+void myMove0(void *ignored)
 {
   myMove(0);
 }
 
-void myMove1(void)
+void myMove1(void *ignored)
 {
   myMove(1);
 }
 
-void myMove2(void)
+void myMove2(void *ignored)
 {
   myMove(2);
 }
@@ -582,12 +583,12 @@ int myNav(MAV_object *o, MAV_mouseEvent *me)
      myYOrig[me->button]= me->y;
 
      /* Start executing myMove function at beginning of frame */
-     mav_frameFn0Add(myMoveFn[me->button]);
+     mav_frameFn0Add(myMoveFn[me->button], NULL);
   }
   else
   {
      /* Stop executing myMove function */
-     mav_frameFn0Rmv(myMoveFn[me->button]);
+     mav_frameFn0Rmv(myMoveFn[me->button], NULL);
   }
 
   /* Also pass event onto ap defined mouse event callback fn */
@@ -601,7 +602,7 @@ int myNav(MAV_object *o, MAV_mouseEvent *me)
 MAV_window *ov;
 MAV_viewParams ovp;
 
-void fixView(void)
+void fixView(void *ignored)
 {
   /* Copy the other windows view */
   ovp= mav_vp_default;
@@ -612,7 +613,7 @@ void fixView(void)
   ovp.up= mav_vp_default.view;
 }
 
-void drawBB(void)
+void drawBB(void *ignored)
 {
   /* Display users BB in overview window */
   mav_BBDisplay(ov, bb);
@@ -647,7 +648,7 @@ int main(int argc, char *argv[])
   MAV_dodec dodec;
 
   /* Initialise the Maverik system */
-  mav_initialiseArgs(&argc, argv);
+  mav_initialise(&argc, argv);
 
   /* Set the SMS display function */
   mav_SMS_displayFn= myDraw;
@@ -657,8 +658,8 @@ int main(int argc, char *argv[])
   mav_windowViewParamsSet(ov, &ovp);
 
   /* Functions to set the overview window view and render the BB */
-  mav_frameFn1Add(fixView);
-  mav_frameFn2Add(drawBB);
+  mav_frameFn1Add(fixView, NULL);
+  mav_frameFn2Add(drawBB, NULL);
 
   /* Create a new class to represent the dodecahedron */
   mav_class_dodec= mav_classNew();
