@@ -1,7 +1,7 @@
 /*
  GNU Maverik - a system for managing display and interaction in 
                Virtual Environment applications.
- Copyright (C) 1999-2000 Advanced Interfaces Group
+ Copyright (C) 1999-2001 Advanced Interfaces Group
 
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
@@ -37,7 +37,7 @@ extern "C" {
 /* #define constants */
 
 #define MAV_VERSION(X,Y) ((X)*256+(Y))
-#define MAV_THIS_VERSION MAV_VERSION(5,4)
+#define MAV_THIS_VERSION MAV_VERSION(6,0)
 
 #define MAV_FALSE 0
 #define MAV_TRUE 1
@@ -47,8 +47,6 @@ extern "C" {
 #define MAV_MAX_CBS 100
 #define MAV_MAX_WIN 10
 
-#define MAV_LIST_SIZE 8
-
 #define MAV_COLOUR 1
 #define MAV_MATERIAL 2
 #define MAV_TEXTURE 3
@@ -96,7 +94,7 @@ extern "C" {
 
 #define mav_vectorNormalise mav_vectorNormalize
 #define mav_initialize mav_initialise
-#define mav_initializeArgs mav_initialiseArgs
+#define mav_initializeNoArgs mav_initialiseNoArgs
 #define mav_stringDisplayCenter mav_stringDisplayCentre 
 
 /* Maverik data types */
@@ -177,26 +175,23 @@ typedef struct MAV_SMS_CLASS {
 
 /* Lists */
 
-typedef struct MAV_LISTSEGMENT {
-  void *contents[MAV_LIST_SIZE];
-  int num_items;
-  struct MAV_LISTSEGMENT *next;
-  struct MAV_LISTSEGMENT *previous;
-} MAV_listSegment;
+typedef struct MAV_LISTITEM {
+  void *data1;
+  void *data2;
+  struct MAV_LISTITEM *next;
+  struct MAV_LISTITEM *prev;
+} MAV_listItem;
 
 typedef struct MAV_LISTPOINTER {
-  int count;
-  MAV_listSegment *the_segment;
-  void **current;
+  MAV_listItem *item;
   struct MAV_LISTPOINTER *next;
 } MAV_listPointer;
 
 typedef struct {
   int length;
-  char ordered;
-  MAV_listSegment *first;
-  MAV_listSegment *last;
-  MAV_listPointer *pointer;
+  MAV_listItem *head;
+  MAV_listItem *tail;
+  MAV_listPointer *current;
 } MAV_list;
 
 /* Palette */
@@ -389,19 +384,23 @@ MAV_SMSCallbackFn mav_SMSCallbackQuery(MAV_SMSCallback *scb, MAV_SMS *s);
 /* Lists */
 
 MAV_list *mav_listNew(void);
-MAV_list *mav_listOrderedNew(void);
-void mav_listDelete(MAV_list *l); 
-void mav_listEmpty(MAV_list *l);
 void mav_listItemAdd(MAV_list *l, void *d);
 void mav_listItemRmv(MAV_list *l, void *d);
+int  mav_listItemNext(MAV_list *l, void **d);
+int  mav_listItemContains(MAV_list *l, void *d);
 void mav_listPointerReset(MAV_list *l);
 void mav_listPointerPush(MAV_list *l);
 void mav_listPointerPop(MAV_list *l);
-int  mav_listItemNext(MAV_list *l, void **d);
+void mav_listEmpty(MAV_list *l);
+void mav_listDelete(MAV_list *l); 
 int  mav_listSize(MAV_list *l);
-int  mav_listItemContains(MAV_list *l, void *d);
 void mav_listPrint(char *s, MAV_list *l);
 
+void mav_listItemsAdd(MAV_list *l, void *d1, void *d2);
+void mav_listItemsRmv(MAV_list *l, void *d1, void *d2);
+int  mav_listItemsNext(MAV_list *l, void **d1, void **d2);
+int  mav_listItemsContains(MAV_list *l, void *d1, void *d2);
+
 /* Window */
 
 MAV_window *mav_windowNew(int x, int y, int w, int h, char *name, char *disp);
@@ -427,19 +426,19 @@ void mav_viewParamsFixed(MAV_window *w);
 
 /* Frame control */
 
-typedef void (*MAV_frameFn)(void);
+typedef void (*MAV_frameFn)(void *);
 void mav_frameBegin(void);
 void mav_frameEnd(void);
-void mav_frameFn0Add(MAV_frameFn fn);
-void mav_frameFn0Rmv(MAV_frameFn fn);
-void mav_frameFn1Add(MAV_frameFn fn);
-void mav_frameFn1Rmv(MAV_frameFn fn);
-void mav_frameFn2Add(MAV_frameFn fn);
-void mav_frameFn2Rmv(MAV_frameFn fn);
-void mav_frameFn3Add(MAV_frameFn fn);
-void mav_frameFn3Rmv(MAV_frameFn fn);
-void mav_frameFn4Add(MAV_frameFn fn);
-void mav_frameFn4Rmv(MAV_frameFn fn);
+void mav_frameFn0Add(MAV_frameFn fn, void *d);
+void mav_frameFn0Rmv(MAV_frameFn fn, void *d);
+void mav_frameFn1Add(MAV_frameFn fn, void *d);
+void mav_frameFn1Rmv(MAV_frameFn fn, void *d);
+void mav_frameFn2Add(MAV_frameFn fn, void *d);
+void mav_frameFn2Rmv(MAV_frameFn fn, void *d);
+void mav_frameFn3Add(MAV_frameFn fn, void *d);
+void mav_frameFn3Rmv(MAV_frameFn fn, void *d);
+void mav_frameFn4Add(MAV_frameFn fn, void *d);
+void mav_frameFn4Rmv(MAV_frameFn fn, void *d);
 
 /* Palette */
 
@@ -565,8 +564,8 @@ void mav_moduleDump(void);
 
 /* Misc */
 
-void mav_initialise(void);
-void mav_initialiseArgs(int *argc, char *argv[]);
+void mav_initialise(int *argc, char *argv[]);
+void mav_initialiseNoArgs(void);
 char *mav_kernelID(void);
 void *mav_malloc(int amount);
 void *mav_calloc(int nelem, int elemsize);
@@ -644,6 +643,7 @@ extern int mav_opt_stencilBuf;
 extern int mav_opt_destAlpha;
 extern int mav_opt_fixedRnd;
 extern int mav_opt_shareContexts;
+extern int mav_opt_bindTextures;
 extern int mav_opt_finish;
 extern int mav_opt_flush;
 
