@@ -1,7 +1,7 @@
 /*
  GNU Maverik - a system for managing display and interaction in 
                Virtual Environment applications.
- Copyright (C) 1999-2000 Advanced Interfaces Group
+ Copyright (C) 1999-2001 Advanced Interfaces Group
 
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
@@ -26,7 +26,7 @@
 */
 
 
-#ifdef WIN32
+#if defined(WIN32) && !defined(MAV_CYGWIN)
 #pragma warning( disable : 4244 ) /* '=' : conversion from 'const double ' to 'float ', possible loss of data */
 #pragma warning( disable : 4018 ) /* '<' : signed/unsigned mismatch */
 #pragma warning( disable : 4305 ) /* '=' : truncation from 'const double ' to 'float ' */
