@@ -1,7 +1,7 @@
 /*
  GNU Maverik - a system for managing display and interaction in 
                Virtual Environment applications.
- Copyright (C) 1999-2000 Advanced Interfaces Group
+ Copyright (C) 1999-2001 Advanced Interfaces Group
 
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
@@ -55,6 +55,9 @@ int mavlib_vrml97SphereCount;
 int mavlib_vrml97IFSCount;
 int mavlib_vrml97IFSFaceCount;
 int mavlib_vrml97IFSVertCount;
+int mavlib_vrml97ILSCount;
+int mavlib_vrml97ILSLineCount;
+int mavlib_vrml97ILSVertCount;
 
 /* Casts to convert generic node into a specfic type. Note that is*Node retuns true if it is */
 /* an instance node which refers to the queried note type. So, these casts need to either */
@@ -116,6 +119,13 @@ IndexedFaceSetNode *mavlib_castToIndexedFaceSetNode(Node *n)
   return rv;
 }
 
+IndexedLineSetNode *mavlib_castToIndexedLineSetNode(Node *n)
+{
+  IndexedLineSetNode *rv= (IndexedLineSetNode *) n;
+  if (n->isInstanceNode()) rv= (IndexedLineSetNode *) mavlib_getReferenceNode(n);
+  return rv;
+}
+
 
 
 /* Routine to generate a box */
@@ -741,6 +751,143 @@ MAV_object *mavlib_dealWithIndexedFaceSetNode(IndexedFaceSetNode *n, MAV_surface
 
 
 
+/* Routine to generate an indexed line set */
+
+MAV_object *mavlib_dealWithIndexedLineSetNode(IndexedLineSetNode *n, MAV_surfaceParams *sp, MAV_matrix m)
+{
+  int i, idx, idxbk, np=0, nv=0;
+  CoordinateNode *pts= NULL; 
+  MAV_polyline *polyline;
+  float v[3];
+  MAV_object *o;
+  int n_getNCoordIndexes= n->getNCoordIndexes();
+  int pts_getNPoints;
+
+  /* Get the coordinates node */
+  pts= n->getCoordinateNodes();
+  if (pts) pts_getNPoints= pts->getNPoints();
+
+  if (!pts) {
+    if (mav_opt_output==MAV_VERBOSE) fprintf(stderr, "Warning: can not find the indexed line set coordinate node, ignoring\n");
+    return NULL;
+  }
+
+  /* Misc traps */
+  if (n->getColorNodes()) if (mav_opt_output==MAV_VERBOSE) fprintf(stderr, "Warning: colour not yet supported, ignoring\n");
+
+  /* Work with a local copy of the coord indexes for efficiency */
+  if (n_getNCoordIndexes==0) {
+    if (mav_opt_output==MAV_VERBOSE) fprintf(stderr, "Warning: indexed line set contains no indices, ignoring\n");
+    return NULL;
+  }    
+  int *coordIdx= new int[n_getNCoordIndexes];
+
+  /* Copy indexes and count number of lines and vertices */
+  for (i=0; i<n_getNCoordIndexes; i++) {
+    coordIdx[i]= n->getCoordIndexNext();
+    if (coordIdx[i]==-1)
+    {
+      np++;
+    }
+    else
+    {
+      nv++;
+    }
+  }
+
+  /* Last line may be implicit rather than have a -1 */
+  if (coordIdx[n_getNCoordIndexes-1]!=-1) np++;
+
+  /* Work with a local copy of the points for efficiency */
+  if (pts_getNPoints==0) {
+    if (mav_opt_output==MAV_VERBOSE) fprintf(stderr, "Warning: indexed line set contains no points, ignoring\n");
+    return NULL;
+  }
+  float *ptsIdx= new float[pts_getNPoints*3];
+  for (i=0; i<pts_getNPoints; i++) pts->getPointNext(&ptsIdx[i*3]);
+
+  /* Create polyline to represent the indexed line set */
+  if (mav_opt_output==MAV_VERBOSE) fprintf(stderr, "\rBuilding objects... Object %i - polyline with %i lines and %i vertices      ", mavlib_nodeObjCount, np, nv); 
+  mavlib_vrml97ILSCount++;
+  mavlib_vrml97ILSLineCount+= np;
+  mavlib_vrml97ILSVertCount+= nv;
+
+  if (fabs(m.mat[0][0]-m.mat[1][1])>0.01 || fabs(m.mat[0][0]-m.mat[2][2])>0.01) mavlib_matScaleWarn++;
+
+  polyline = (MAV_polyline *) mav_malloc(sizeof(MAV_polyline));
+  polyline->nlines = np;
+  polyline->np= (int *) mav_malloc(polyline->nlines*sizeof(int));
+  polyline->closed= (int *) mav_malloc(polyline->nlines*sizeof(int));
+  polyline->vert= (MAV_vector **) mav_malloc(polyline->nlines*sizeof(MAV_vector *));
+  polyline->sp= (MAV_surfaceParams **) mav_malloc(polyline->nlines*sizeof(MAV_surfaceParams *));
+  polyline->matrix= m;
+
+  idx=0;
+  for (i=0; i<polyline->nlines; i++) {
+
+    /* Count number of vertices in this line */
+    nv=0;
+    idxbk= idx;
+    while (!(idx==n_getNCoordIndexes || coordIdx[idx]==-1)) {
+      nv++;
+      idx++;
+    }
+
+    polyline->closed[i] = MAV_FALSE;
+    if (nv>=2)
+    {
+      /* Malloc of room for the vertices */
+      polyline->np[i]= nv;
+      polyline->vert[i]= (MAV_vector *) mav_malloc(polyline->np[i]*sizeof(MAV_vector));
+      polyline->sp[i]= sp;
+
+      /* Store the vertices */
+      nv=0;
+      idx= idxbk;
+      while (!(idx==n_getNCoordIndexes || coordIdx[idx]==-1)) {
+	
+	/* Ensure that the index is valid */
+	if (coordIdx[idx] >= pts_getNPoints) 
+	{
+	  if (mav_opt_output==MAV_VERBOSE) fprintf(stderr, "Warning: coordinate index too big, setting to max\n");
+	  v[0]= ptsIdx[(pts_getNPoints-1)*3+0];
+	  v[1]= ptsIdx[(pts_getNPoints-1)*3+1];
+	  v[2]= ptsIdx[(pts_getNPoints-1)*3+2];
+	}
+	else
+	{
+	  v[0]= ptsIdx[coordIdx[idx]*3+0];
+	  v[1]= ptsIdx[coordIdx[idx]*3+1];
+	  v[2]= ptsIdx[coordIdx[idx]*3+2];
+	}
+
+	polyline->vert[i][polyline->np[i]-1-nv].x= v[0];
+	polyline->vert[i][polyline->np[i]-1-nv].y= v[1];
+	polyline->vert[i][polyline->np[i]-1-nv].z= v[2];    
+
+	nv++;
+	idx++;
+      }
+    }    
+    else
+    {
+      if (mav_opt_output==MAV_VERBOSE) fprintf(stderr, "Warning: line with less than 2 vertices, ignoring\n");
+      polyline->np[i]=0;
+    }
+
+    idx++;
+  }
+
+  delete coordIdx;
+  delete ptsIdx;
+
+  o= mav_objectNew(mav_class_polyline, polyline);
+
+  return o;
+}
+
+
+
 /* Routine to build a material */
 
 MAV_surfaceParams *mavlib_dealWithMaterialNode(MaterialNode *n)
@@ -915,6 +1062,10 @@ MAV_object *mavlib_dealWithShapeNode(ShapeNode *n, MAV_matrix m)
     {
       rv= mavlib_dealWithIndexedFaceSetNode(mavlib_castToIndexedFaceSetNode(gn), sp, m, texTran);
     } 
+    else if (gn->isIndexedLineSetNode()) 
+    {
+      rv= mavlib_dealWithIndexedLineSetNode(mavlib_castToIndexedLineSetNode(gn), sp, m);
+    }
     else if (gn->isBoxNode()) 
     {
       rv= mavlib_dealWithBoxNode(mavlib_castToBoxNode(gn), sp, m);
@@ -1073,6 +1224,9 @@ int mav_compositeReadVRML97(char *filename, MAV_composite *c, MAV_matrix m)
   mavlib_vrml97IFSCount=0;
   mavlib_vrml97IFSFaceCount=0;
   mavlib_vrml97IFSVertCount=0;
+  mavlib_vrml97ILSCount=0;
+  mavlib_vrml97ILSLineCount=0;
+  mavlib_vrml97ILSVertCount=0;
 
   if (mav_opt_output==MAV_VERBOSE) fprintf(stderr, "Parsing VRML97 file %s... ", filename);
 
@@ -1104,6 +1258,7 @@ int mav_compositeReadVRML97(char *filename, MAV_composite *c, MAV_matrix m)
     if (mavlib_vrml97ConeCount) fprintf(stderr, " %i cones\n", mavlib_vrml97ConeCount);
     if (mavlib_vrml97SphereCount) fprintf(stderr, " %i spheres\n", mavlib_vrml97SphereCount);
     if (mavlib_vrml97IFSCount) fprintf(stderr, " %i indexed face sets totaling %i faces and %i vertices\n", mavlib_vrml97IFSCount, mavlib_vrml97IFSFaceCount, mavlib_vrml97IFSVertCount);   
+    if (mavlib_vrml97ILSCount) fprintf(stderr, " %i indexed line sets totaling %i lines and %i vertices\n", mavlib_vrml97ILSCount, mavlib_vrml97ILSLineCount, mavlib_vrml97ILSVertCount);   
     if (mavlib_matScaleWarn) fprintf(stderr, "Warning: %i objects had non-uniformly scaled matrix, this may lead to intersection problems\n", mavlib_matScaleWarn);
   }
 
@@ -1129,6 +1284,9 @@ int mav_compositeReadVRML97(char *filename, MAV_composite *c, MAV_matrix m)
     mav_SMSDelete(mavlib_nodeObj, 0);
   }
 
+  /* Make the SMS unselectable - selection must come via the MAV_SMSObj */
+  mav_SMSSelectabilitySet(smsobj->sms, mav_win_all, MAV_FALSE);
+
   /* Build composite and add the SMS object */
   c->numobj= 1;
   c->obj= (MAV_object **) mav_malloc(c->numobj*sizeof(MAV_object *));
