@@ -1,7 +1,7 @@
 /*
  GNU Maverik - a system for managing display and interaction in 
                Virtual Environment applications.
- Copyright (C) 1999-2000 Advanced Interfaces Group
+ Copyright (C) 1999-2001 Advanced Interfaces Group
 
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
@@ -35,13 +35,17 @@
 
 #include "maverik.h"
 #include "mav_lwo.h"
-char *strdup (const char *s1);
 
+#ifdef WIN32
+#include <windows.h>
+#endif
 #include <GL/glu.h>
-#include <GL/gl.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#if !defined(WIN32) || defined(MAV_CYGWIN)
+char *strdup (const char *s1);
+#endif
 
 typedef struct {
   unsigned int length;
@@ -786,12 +790,16 @@ int mavlib_LWOBTriCount;
 int mavlib_LWOBVertCount;
 MAVLIB_LWOBTriangleList *mavlib_LWOBCurrTri;
 
-void mavlib_LWOBTessBgn(GLenum type)
+#ifndef CALLBACK
+#define CALLBACK
+#endif
+
+void CALLBACK mavlib_LWOBTessBgn(GLenum type)
 {
     mavlib_LWOBVertCount=0;
 }
 
-void mavlib_LWOBTessv3f(void *data)
+void CALLBACK mavlib_LWOBTessv3f(void *data)
 {
     if (mavlib_LWOBVertCount==0) 
     {
@@ -808,7 +816,7 @@ void mavlib_LWOBTessv3f(void *data)
     if (mavlib_LWOBVertCount==3) mavlib_LWOBVertCount=0;
 }
 
-void mavlib_LWOBTessEnd()
+void CALLBACK mavlib_LWOBTessEnd(void)
 {
     if (mavlib_LWOBVertCount!=0) 
     {
@@ -817,11 +825,11 @@ void mavlib_LWOBTessEnd()
     }
 }
 
-void mavlib_LWOBTessEdge()
+void CALLBACK mavlib_LWOBTessEdge(GLboolean flag)
 {
 }
 
-void mavlib_LWOBTessErr(GLenum en)
+void CALLBACK mavlib_LWOBTessErr(GLenum en)
 {
     char message[]="Warning - Triangulation failed because there were";
     char * buf=(char *) mav_malloc(strlen((char *)gluErrorString(en))+strlen(message)+2);
@@ -862,7 +870,7 @@ int mav_compositeReadLWO(char *filename, MAV_composite *c, MAV_matrix mat)
     facet->vert=NULL;
     facet->sp=NULL;
     facet->userdef=NULL;
-    facet->matrix=MAV_ID_MATRIX;
+    facet->matrix=mat;
     facet->npolys=0;
 
     if(mavlib_LWOBparse_file(&surfaces, &points, &polygons, &numpoints, filename))
