@@ -1,7 +1,7 @@
 /*
  GNU Maverik - a system for managing display and interaction in 
                Virtual Environment applications.
- Copyright (C) 1999-2000 Advanced Interfaces Group
+ Copyright (C) 1999-2001 Advanced Interfaces Group
 
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
@@ -27,12 +27,14 @@
 
 
 #include "mavlib_kernel.h"
-char *strdup (const char *s1);
 #include <string.h>
+#if !defined(WIN32) || defined(MAV_CYGWIN)
+char *strdup (const char *s1);
+#endif
 #include <stdlib.h>
 #include <stdio.h>
 #include <ctype.h>
-#if !defined(WIN32) && !defined(macintosh)
+#if defined(MAV_CYGWIN) || (!defined(WIN32) && !defined(macintosh))
 #include <unistd.h>
 #ifdef MAV_LINUX
 #ifndef MAV_FREEBSD
@@ -76,6 +78,8 @@ int mav_opt_destAlpha= MAV_FALSE;
 int mav_opt_multiSample= MAV_DONTCARE;
 int mav_this_version= MAV_THIS_VERSION;
 void *mavlib_dlh= NULL;
+int mav_opt_bindTextures= MAV_UNDEFINED;
+int mav_opt_shareContexts= MAV_UNDEFINED;
 
 /* For passing options to modules. Need global vars to cope cleanly with */
 /* modules initialised from the application. */
@@ -88,7 +92,7 @@ FILE *mav_userconf= NULL;
 
 char *mav_kernelID(void)
 {
-  return "GNU Maverik v5.4";
+  return "GNU Maverik v6.0";
 }
 
 #if defined(WIN32) || defined(macintosh)
@@ -212,6 +216,31 @@ void mavlib_kernelCmdLineParse(int argc, char *argv[])
 	mav_opt_multiSample= MAV_FALSE;
 	argv[cur_arg]= NULL;
       }
+
+      else if (strcmp(arg_name, "-sharecontexts") == 0)
+      {
+	mav_opt_shareContexts= MAV_TRUE;
+	argv[cur_arg]= NULL;
+      }
+
+      else if (strcmp(arg_name, "-nosharecontexts") == 0)
+      {
+	mav_opt_shareContexts= MAV_FALSE;
+	argv[cur_arg]= NULL;
+      }
+
+      else if (strcmp(arg_name, "-bindtextures") == 0)
+      {
+	mav_opt_bindTextures= MAV_TRUE;
+	argv[cur_arg]= NULL;
+      }
+
+      else if (strcmp(arg_name, "-nobindtextures") == 0)
+      {
+	mav_opt_bindTextures= MAV_FALSE;
+	argv[cur_arg]= NULL;
+      }
+
       else if (strcmp(arg_name, "-mavhelp") == 0)
       {
 	printf("Maverik command line options:\n"
@@ -220,7 +249,9 @@ void mavlib_kernelCmdLineParse(int argc, char *argv[])
 	       "  -[no]fixedRnd\t\t\t\tUse the built-in set of 'random' numbers\n"
 	       "  -[no]WMPlacement\t\t\tAllow window manager to place window\n"
 	       "  -[no]singleBuf\t\t\tSingle buffered rendering\n"
-	       "  -[no]multiSample\t\t\tMultisampled rendering\n");
+	       "  -[no]multiSample\t\t\tMultisampled rendering\n"
+	       "  -[no]shareContexts\t\t\tMultiple windows share contexts\n"
+	       "  -[no]bindTextures\t\t\tUse bound textures\n");
 
 	/* suppress output that would otherwise disrupt the options listing */
 	mav_opt_output= MAV_SILENT;
@@ -260,6 +291,16 @@ void mavlib_kernelEnvVarsParse(void)
   {
     mav_opt_multiSample= (strcmp(ev, "0") == 0) ? MAV_FALSE : MAV_TRUE;
   }
+
+  if ((ev= getenv("MAV_SHARECONTEXTS")))
+  {
+    mav_opt_shareContexts= (strcmp(ev, "0") == 0) ? MAV_FALSE : MAV_TRUE;
+  }
+
+  if ((ev= getenv("MAV_BINDTEXTURES")))
+  {
+    mav_opt_bindTextures= (strcmp(ev, "0") == 0) ? MAV_FALSE : MAV_TRUE;
+  }
 }
 
 
@@ -311,6 +352,16 @@ void mavlib_kernelConfigFileParse(FILE *cf_file)
       {
 	mav_opt_multiSample= (strcmp(val, "0") == 0) ? MAV_FALSE : MAV_TRUE;
       }
+
+      else if (strcmp(opt, "sharecontexts") == 0 && mav_opt_shareContexts == MAV_DONTCARE)
+      {
+	mav_opt_shareContexts= (strcmp(val, "0") == 0) ? MAV_FALSE : MAV_TRUE;
+      }
+
+      else if (strcmp(opt, "bindtextures") == 0 && mav_opt_bindTextures == MAV_DONTCARE)
+      {
+	mav_opt_bindTextures= (strcmp(val, "0") == 0) ? MAV_FALSE : MAV_TRUE;
+      }
     }
   }
 }
@@ -324,20 +375,21 @@ void mavlib_kernelOptionsDefaultSet(void)
   if (mav_opt_fixedRnd == MAV_UNDEFINED) mav_opt_fixedRnd= MAV_FALSE;
   if (mav_opt_singleBuf == MAV_UNDEFINED) mav_opt_singleBuf= MAV_FALSE;
   if (mav_opt_WMPlacement == MAV_UNDEFINED) mav_opt_WMPlacement= MAV_FALSE;
+  if (mav_opt_bindTextures == MAV_UNDEFINED) mav_opt_bindTextures= MAV_TRUE;
+  if (mav_opt_shareContexts == MAV_UNDEFINED) mav_opt_shareContexts= MAV_TRUE;
   /* leave multiSample as DONTCARE, if set as such */
 }
 
 
-void mav_initialise(void)
+void mav_initialiseNoArgs(void)
 {
-  mav_initialiseArgs(NULL, NULL);
+  mav_initialise(NULL, NULL);
 }
 
 
-void mav_initialiseArgs(int *argc_p, char *argv[])
+void mav_initialise(int *argc_p, char *argv[])
 {
   int i;
-  FILE *f;
   char homepath[200];
 
 #if defined(WIN32) || defined(macintosh)
@@ -350,6 +402,7 @@ void mav_initialiseArgs(int *argc_p, char *argv[])
                                   *mav_navigationModuleInit,
                                   *mav_objectsModuleInit, 0};
 #else
+  FILE *f;
   int defaultInit=0;
   char buf[100];
   char confname[]= ".maverikrc";
@@ -394,7 +447,7 @@ void mav_initialiseArgs(int *argc_p, char *argv[])
   mavlib_kernelOptionsDefaultSet();
   
   /* identify the kernel version */
-  if (mav_opt_output==MAV_VERBOSE) fprintf(stderr, "%s - Copyright (C) 1999-2000 Advanced Interfaces Group\n", mav_kernelID());
+  if (mav_opt_output==MAV_VERBOSE) fprintf(stderr, "%s - Copyright (C) 1999-2001 Advanced Interfaces Group\n", mav_kernelID());
 
   /* create kernel defined callbacks to delete an object and SMS and remove an object from an SMS */
   mav_callback_delete= mav_callbackNew();
@@ -409,27 +462,25 @@ void mav_initialiseArgs(int *argc_p, char *argv[])
   mav_class_all= mav_classNew();
 
   /* create a list of all windows, SMS's, palettes and objects  */
-  mav_win_list= mav_listOrderedNew();
-  mav_sms_list= mav_listOrderedNew();
-  mav_palette_list= mav_listOrderedNew();
-  mav_object_list= mav_listOrderedNew();
+  mav_win_list= mav_listNew();
+  mav_sms_list= mav_listNew();
+  mav_palette_list= mav_listNew();
+  mav_object_list= mav_listNew();
 
   /* create a list frame functions */
-  mavlib_frame0_list= mav_listOrderedNew();
-  mavlib_frame1_list= mav_listOrderedNew();
-  mavlib_frame2_list= mav_listOrderedNew();
-  mavlib_frame3_list= mav_listOrderedNew();
-  mavlib_frame4_list= mav_listOrderedNew();
-  mavlib_duringFrame_addList= mav_listOrderedNew();
-  mavlib_duringFrame_rmvList= mav_listOrderedNew();
+  mavlib_frame0_list= mav_listNew();
+  mavlib_frame1_list= mav_listNew();
+  mavlib_frame2_list= mav_listNew();
+  mavlib_frame3_list= mav_listNew();
+  mavlib_frame4_list= mav_listNew();
 
   /* create a list of device functions */
-  mavlib_devicePoll_list= mav_listOrderedNew();
-  mavlib_deviceCalc_list= mav_listOrderedNew();
-  mavlib_deviceEvent_list= mav_listOrderedNew();
+  mavlib_devicePoll_list= mav_listNew();
+  mavlib_deviceCalc_list= mav_listNew();
+  mavlib_deviceEvent_list= mav_listNew();
 
   /* create a list of modules */
-  mav_module_list= mav_listOrderedNew();
+  mav_module_list= mav_listNew();
 
   /* default view params */
   mav_vp_default.eye.x=0;
@@ -460,7 +511,7 @@ void mav_initialiseArgs(int *argc_p, char *argv[])
   /* get hostname */
 #ifdef macintosh
   strcpy(mav_hostName, "Macintosh");
-#elif defined(WIN32)
+#elif defined(WIN32) && !defined(MAV_CYGWIN)
   strcpy(mav_hostName, "Windows"); /* WIN32 */
 #else
   gethostname(mav_hostName, 200);
