@@ -1,7 +1,7 @@
 /*
  GNU Maverik - a system for managing display and interaction in 
                Virtual Environment applications.
- Copyright (C) 1999-2000 Advanced Interfaces Group
+ Copyright (C) 1999-2001 Advanced Interfaces Group
 
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
@@ -31,13 +31,15 @@
 #include <stdio.h>
 #include <string.h>
 #include <math.h>
-#if !defined(WIN32) && !defined(macintosh)
+#if (!defined(WIN32) || defined(MAV_CYGWIN)) && !defined(macintosh)
 #include <sys/types.h>
 #include <unistd.h>
 #endif
 
 
+#if !defined(WIN32) || defined(MAV_CYGWIN)
 char *strdup (const char *s1);
+#endif
 
 MAV_surfaceParams mavlib_surfaceParams={-1,-1,-1,-1};
 MAV_surfaceParams *mav_sp_current= &mavlib_surfaceParams;
@@ -457,7 +459,7 @@ int mavlib_readPPM(char *filename, int *width, int *height, unsigned long **mem)
 
 /* Open PPM file */
 
-  file=fopen(filename, "r");
+  file=fopen(filename, "rb");
   if (!file) {
     if (mav_opt_output==MAV_VERBOSE) fprintf(stderr, "Error: can not read texture file %s, ignoring\n", filename);
     return(MAV_FALSE);
@@ -503,18 +505,6 @@ int mavlib_readPPM(char *filename, int *width, int *height, unsigned long **mem)
   /* if binary, read since white space char */
   if (bin) fscanf(file, "%c", &str[0]);
 
-  /* re-open as binary file, but maintaining position, if appropriate */
-  if (bin) {
-    long offset= ftell(file);
-    fclose(file);
-    file= fopen(filename, "rb");
-    if (!file) {
-      if (mav_opt_output==MAV_VERBOSE) fprintf(stderr, "Error: can not re-open as binary file, ignoring\n");
-      return(MAV_FALSE);
-    }
-    fseek(file, offset, SEEK_SET);
-  }
-
 /* Parse */
   
   *mem=(unsigned long *) mav_malloc(*width**height*sizeof(unsigned long));
@@ -738,7 +728,7 @@ int mav_paletteTextureSet(MAV_palette *p, int index, char *filename)
 #endif
     else
     {
-#if !defined(WIN32) && !defined(macintosh)
+#if (!defined(WIN32) || defined(MAV_CYGWIN)) && !defined(macintosh)
       char buf[500], f1[500], f2[500];
       int srv;
 
@@ -797,7 +787,7 @@ int mav_paletteTextureSet(MAV_palette *p, int index, char *filename)
 	mav_free(p->texlist[index].mem);
 
 	{
-#if !defined(WIN32) && !defined(macintosh)
+#if (!defined(WIN32) || defined(MAV_CYGWIN)) && !defined(macintosh)
 	  char buf[500], f1[500], f2[500];
 	  int srv;
 
