@@ -1,7 +1,7 @@
 /*
  GNU Maverik - a system for managing display and interaction in 
                Virtual Environment applications.
- Copyright (C) 1999-2000 Advanced Interfaces Group
+ Copyright (C) 1999-2001 Advanced Interfaces Group
 
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
@@ -28,7 +28,9 @@
 
 #include "mavlib_objects.h"
 #include <string.h>
+#if !defined(WIN32) || defined(MAV_CYGWIN)
 char *strdup (const char *s1);
+#endif
 #include <stdio.h>
 #include <math.h>
 #include <stdlib.h>
@@ -788,7 +790,7 @@ int mavlib_compositeAC3DRead(char *filename, MAV_composite *c, MAV_matrix m)
 
   /* parse the lot counting up number of surfaces, lines and objects*/
 
-  oi_list= mav_listOrderedNew();
+  oi_list= mav_listNew();
 
   while (!mavlib_ac3d_parseEOF()) {
     mavlib_ac3d_parseString(str);
