@@ -1,7 +1,7 @@
 /*
  GNU Maverik - a system for managing display and interaction in 
                Virtual Environment applications.
- Copyright (C) 1999-2000 Advanced Interfaces Group
+ Copyright (C) 1999-2001 Advanced Interfaces Group
 
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
@@ -393,8 +393,8 @@ int mav_ctorusBB2(MAV_object *obj, MAV_BB *bb)
  *                  than once.
  */
 
-#include    <math.h>
-#if defined(WIN32) || defined(macintosh)
+#include <math.h>
+#if (defined(WIN32) && !defined(MAV_CYGWIN)) || defined(macintosh)
 double cbrt(double x) {return pow(x, (double)(1.0/3.0));}
 #else
 double cbrt(double x);
