@@ -1,7 +1,7 @@
 /*
  GNU Maverik - a system for managing display and interaction in 
                Virtual Environment applications.
- Copyright (C) 1999-2000 Advanced Interfaces Group
+ Copyright (C) 1999-2001 Advanced Interfaces Group
 
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
@@ -36,12 +36,14 @@
 #include <dlfcn.h>
 #endif
 #include <string.h>
-#if !defined(WIN32) && !defined(macintosh)
+#if (!defined(WIN32) || defined(MAV_CYGWIN)) && !defined(macintosh)
 #include <sys/types.h>
 #include <unistd.h>
 #endif
 
+#if !defined(WIN32) || defined(MAV_CYGWIN)
 char *strdup(const char *);
+#endif
 
 extern int mavlib_voodoo;
 
@@ -172,7 +174,7 @@ int mavlib_checkWindowEvents(void)
 int mavlib_restrictLastX;
 int mavlib_restrictLastY;
 
-void mavlib_restrictMouse(void)
+void mavlib_restrictMouse(void *ignored)
 {
   if (mav_opt_restrictMouse) {
     /* Is pointer outside of window? */
@@ -775,7 +777,7 @@ char *mav_windowsModuleID(void)
 
 int mav_windowsModuleInit(void)
 {
-#ifndef WIN32
+#if !defined(WIN32) || defined(MAV_CYGWIN)
   FILE *f;
   char filename[500];
 #endif
@@ -1005,20 +1007,48 @@ int mav_windowsModuleInit(void)
     }
     else
     {
-#if defined(WIN32) || defined(macintosh)
+#if (defined(WIN32) && !defined(MAV_CYGWIN)) || defined(macintosh)
       strcpy(buf, "Maverik"); /* WIN32 */
 #else
       sprintf(filename, "/tmp/mavname%i", getpid());
+#ifdef MAV_CYGWIN
+      sprintf (buf, "ps a | awk '{if ($1==%i) print $4}' 2>&1 >%s", getpid(), filename);
+#else
 #ifdef MAV_LINUX
       sprintf(buf, "ps a | awk '{if ($1==%i) print $5}' 2>&1 >%s", getpid(), filename);
 #else
       sprintf(buf, "ps -f | awk '{if ($2==%i) print $8}' 2>&1 >%s", getpid(), filename);
 #endif
+#endif
+
       system(buf);
       f= fopen(filename, "r");
       if (f) 
       {
 	if (fscanf(f, "%s", buf)!=1) strcpy(buf, "Maverik");
+#ifdef MAV_CYGWIN
+        else {
+	  int last_slash= -1;
+	  int i= 0;
+
+/* code to strip path from executable */
+	  while (buf[i] != 0) {
+	    if (buf[i] == '/') last_slash= i;
+	    i ++;
+	  }
+
+	  if (last_slash != -1) {
+	    i= 0;
+	    last_slash ++;
+	    while (buf[i+last_slash] != 0) {
+	      buf[i]= buf[i+last_slash];
+	      i ++;
+	    }
+	    buf[i]= 0;
+	  }
+        }
+#endif
+
 	fclose(f);
       }
       else
@@ -1092,7 +1122,7 @@ int mav_windowsModuleInit(void)
   }
   mavlib_restrictLastX= lw/2;
   mavlib_restrictLastY= lh/2;
-  mav_frameFn1Add(mavlib_restrictMouse);
+  mav_frameFn1Add(mavlib_restrictMouse, NULL);
 
 /* Define the mouse's surface params */
 
